/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

        Authors:    David Ducos, Percona (david dot ducos at percona dot com)
*/
#include "myloader.h"

void initialize_worker_index(struct configuration *conf);
void wait_index_worker_to_finish();
void create_index_shutdown_job(struct configuration *conf);
void start_optimize_keys_all_tables();
void enqueue_indexes_if_possible(struct configuration *conf);
void enqueue_index_for_dbt_if_possible(struct configuration *conf, struct db_table * dbt);
